# remirepo spec file for php-pecl-timecop
#
# Copyright (c) 2017-2019 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%if 0%{?scl:1}
%global sub_prefix %{scl_prefix}
%scl_package        php-pecl-timecop
%endif

%global pecl_name   timecop
# Disable ZTS for now
# PR 45 seems needed, but raise segfaults
%global with_zts    0
%global with_tests  %{?_without_tests:0}%{!?_without_tests:1}
%if "%{php_version}" < "5.6"
%global ini_name    %{pecl_name}.ini
%else
%global ini_name    40-%{pecl_name}.ini
%endif

Summary:       Time travel and freezing extension
Name:          %{?sub_prefix}php-pecl-timecop
Version:       1.2.10
Release:       9%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
License:       MIT
URL:           http://pecl.php.net/package/%{pecl_name}
Source0:       http://pecl.php.net/get/%{pecl_name}-%{version}.tgz

# https://github.com/hnw/php-timecop/pull/44 Support strict_types
Patch0:        https://patch-diff.githubusercontent.com/raw/hnw/php-timecop/pull/44.patch
# https://github.com/hnw/php-timecop/pull/45 for ZTS
Patch1:        https://patch-diff.githubusercontent.com/raw/hnw/php-timecop/pull/45.patch
# Upstream patches
Patch2:        https://github.com/hnw/php-timecop/commit/70fe4e091eadb40a57b90c0d6345b7722b6817db.patch
Patch3:        https://github.com/hnw/php-timecop/commit/06897991d042115185fd98ff4e79569fbe51e0bf.patch
Patch4:        https://github.com/hnw/php-timecop/commit/7e8816a4be83c43f3a0b373fe3d619dff5bc5fd8.patch
Patch5:        https://github.com/hnw/php-timecop/commit/ab34c77a5a9c8611d1fc87601fcd72c9defb809d.patch
Patch6:        https://github.com/hnw/php-timecop/commit/61748491a773a7f47694e2fd97dc2c3c61ce9f18.patch

BuildRequires: %{?dtsprefix}gcc
BuildRequires: %{?scl_prefix}php-devel
BuildRequires: %{?scl_prefix}php-pear

Requires:      %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:      %{?scl_prefix}php(api) = %{php_core_api}
%{?_sclreq:Requires: %{?scl_prefix}runtime%{?_sclreq}%{?_isa}}

Obsoletes:     %{?scl_prefix}php-%{pecl_name}               < 1.2.7
Provides:      %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:      %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:      %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:      %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}
%if "%{?scl_prefix}" != "%{?sub_prefix}"
Provides:      %{?scl_prefix}php-pecl-%{pecl_name}          = %{version}-%{release}
Provides:      %{?scl_prefix}php-pecl-%{pecl_name}%{?_isa}  = %{version}-%{release}
%endif

%if "%{?vendor}" == "Remi Collet" && 0%{!?scl:1} && 0%{?rhel}
# Other third party repo stuff
%if "%{php_version}" > "7.2"
Obsoletes:     php72u-pecl-%{pecl_name} <= %{version}
Obsoletes:     php72w-pecl-%{pecl_name} <= %{version}
%endif
%if "%{php_version}" > "7.3"
Obsoletes:      php73-pecl-%{pecl_name} <= %{version}
Obsoletes:     php73w-pecl-%{pecl_name} <= %{version}
%endif
%if "%{php_version}" > "7.4"
Obsoletes:      php74-pecl-%{pecl_name} <= %{version}
Obsoletes:     php74w-pecl-%{pecl_name} <= %{version}
%endif
%endif

%if 0%{?fedora} < 20 && 0%{?rhel} < 7
# Filter shared private
%{?filter_provides_in: %filter_provides_in %{_libdir}/.*\.so$}
%{?filter_setup}
%endif


%description
A PHP extension providing "time travel" and "time freezing" capabilities,
inspired by ruby timecop gem.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -qc
mv %{pecl_name}-%{version} NTS

# Don't install/register tests
sed -e 's/role="test"/role="src"/' \
    %{?_licensedir:-e  '/LICENSE/s/role="doc"/role="src"/' } \
    -i package.xml

cd NTS
#patch0 -p1 -b .pr44
#patch1 -p1 -b .pr45
%patch2 -p1 -b .up1
%patch3 -p1 -b .up2
%patch4 -p1 -b .up3
%patch5 -p1 -b .up4
%patch6 -p1 -b .up5

# Sanity check, really often broken
extver=$(sed -n '/#define PHP_TIMECOP_VERSION/{s/.* "//;s/".*$//;p}' php_timecop.h)
if test "x${extver}" != "x%{version}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}.
   exit 1
fi
cd ..

%if %{with_zts}
# duplicate for ZTS build
cp -pr NTS ZTS
%endif

# Drop in the bit of configuration
cat << 'EOF' | tee %{ini_name}
; Enable '%{summary}' module
extension = %{pecl_name}.so

; Configuration
;timecop.func_override = 1
;timecop.sync_request_time = 1
EOF


%build
%{?dtsenable}

cd NTS
%{_bindir}/phpize
%configure \
    --with-php-config=%{_bindir}/php-config \
    --with-libdir=%{_lib} \
    --enable-timecop
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%{_bindir}/zts-phpize
%configure \
    --with-php-config=%{_bindir}/zts-php-config \
    --with-libdir=%{_lib} \
    --enable-timecop
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

# Install the NTS stuff
make -C NTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
# Install the ZTS stuff
make -C ZTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 NTS/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
if [ -f %{php_extdir}/calendar.so ]; then
    MOD="-d extension=calendar.so"
fi

: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

%if %{with_tests}
cd NTS
: Upstream test suite  for NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="-n $MOD -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
NO_INTERACTION=1 \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php --show-diff
%endif

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

%if %{with_tests}
cd ../ZTS
: Upstream test suite  for ZTS extension
TEST_PHP_EXECUTABLE=%{__ztsphp} \
TEST_PHP_ARGS="-n $MOD -d extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so" \
NO_INTERACTION=1 \
REPORT_EXIT_STATUS=1 \
%{__ztsphp} -n run-tests.php --show-diff
%endif
%endif


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{pecl_name} >/dev/null || :
fi
%endif


%files
%doc %{pecl_docdir}/%{pecl_name}
%{?_licensedir:%license NTS/LICENSE}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Sun Dec 15 2019 Remi Collet <remi@remirepo.net> - 1.2.10-9
- add upstream patches for 7.3 and 7.4
- disable ZTS for now

* Thu Feb 28 2019 Remi Collet <remi@remirepo.net> - 1.2.10-5
- fix strict_types support, patch from
  https://github.com/hnw/php-timecop/pull/44
- fix ZTS support, patch from
  https://github.com/hnw/php-timecop/pull/45

* Wed Dec 12 2018 Remi Collet <remi@remirepo.net> - 1.2.10-4
- ignore failing test with 7.3, reported as
  https://github.com/hnw/php-timecop/issues/42

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 1.2.10-3
- rebuild for 7.3.0beta2 new ABI

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 1.2.10-2
- rebuild for 7.3.0alpha4 new ABI

* Thu Nov 23 2017 Remi Collet <remi@remirepo.net> - 1.2.10-1
- Update to 1.2.10

* Wed Nov 22 2017 Remi Collet <remi@remirepo.net> - 1.2.8-3
- add upstream patch for PHP 7.2

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 1.2.8-2
- rebuild for PHP 7.2.0beta1 new API

* Fri Jul  7 2017 Remi Collet <remi@remirepo.net> - 1.2.8-1
- Update to 1.2.8 (no change)

* Fri Jul  7 2017 Remi Collet <remi@remirepo.net> - 1.2.7-1
- rename to php-pecl-timecop
- use sources from pecl
- update to 1.2.7
- open https://github.com/hnw/php-timecop/pull/21 - bad roles
- open https://github.com/hnw/php-timecop/pull/22 - missing file

* Tue Jul  4 2017 Remi Collet <remi@remirepo.net> - 1.2.6-1
- new package, version 1.2.6 (beta)
